==> react-ui-library-7.1.0.tgz: package/src/components/Input.js <==
import React from 'react'
import PropTypes from 'prop-types'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import ExclamationCircle from './ExclamationCircle'
import theme from './theme'
import splitProps from './utils/splitProps'
const { minorScale, majorScale } = theme

const styles = css({
  color: theme.backgrounds.white.textColor,
  boxShadow: `inset 0 0 0 1px ${theme.backgrounds.white.borderColor}`,
  '&:focus, &:active': {
    boxShadow: `inset 0 0 0 1px ${theme.colors.primary}`
  }
})

function useControlSizes ({ size, ...props }) {
  const sizes = theme.controlSizes[size]

  return {
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: size === 'default' ? minorScale(3) : majorScale(2),
    ...props
  }
}

const Input = ({ warning, className, ...props }) => {
  // Tries to treat this component as a single box
  const { matchedProps, unmatchedProps } = splitProps(useControlSizes(props),
    /margin|width|height|display/gi)

  return (
    <Box position='relative' display='flex' {...matchedProps}>
      {warning ? <ExclamationCircle position='absolute' top='50%' marginLeft='-5px' marginTop='-6px' /> : null}
      <Box is='input' className={cx(`${styles}`, className)} flex='1' {...unmatchedProps} />
    </Box>
  )
}

Input.propTypes = {
  warning: PropTypes.bool,
  size: PropTypes.oneOf(Object.keys(theme.controlSizes))
}

Input.defaultProps = {
  rounded: true,
  size: 'default'
}

Input.displayName = 'Input'

export default Input

==> react-ui-library-7.3.0.tgz: package/src/components/Input.js <==
import React from 'react'
import PropTypes from 'prop-types'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import ExclamationCircle from './ExclamationCircle'
import theme from './theme'
import splitProps from './utils/splitProps'
const { minorScale, majorScale, controlStateStyles } = theme

const styles = css({
  color: controlStateStyles.default.color,
  border: controlStateStyles.default.border,
  transition: controlStateStyles.default.transition,
  '&:focus': {
    border: controlStateStyles.focus.border,
    boxShadow: controlStateStyles.focus.boxShadow
  }
})

function useControlSizes ({ size, ...props }) {
  const sizes = theme.controlSizes[size]

  return {
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: size === 'small' ? minorScale(3) : majorScale(2),
    ...props
  }
}

const Input = ({ warning, className, ...props }) => {
  // Tries to treat this component as a single box
  const { matchedProps, unmatchedProps } = splitProps(useControlSizes(props),
    /margin|width|height|display/gi)

  return (
    <Box position='relative' display='flex' {...matchedProps}>
      {warning ? <ExclamationCircle position='absolute' top='50%' marginLeft='-5px' marginTop='-6px' /> : null}
      <Box is='input' className={cx(`${styles}`, className)} flex='1' {...unmatchedProps} />
    </Box>
  )
}

Input.propTypes = {
  warning: PropTypes.bool,
  size: PropTypes.oneOf(Object.keys(theme.controlSizes))
}

Input.defaultProps = {
  rounded: true,
  size: 'default'
}

Input.displayName = 'Input'

export default Input
